//do-file for "Survival analysis"
//Open the dataset Life_Table1.dta

stset survival_week												//sets the data in survival mode

ltable survival_week event 										//this commands produces lifetables
ltable survival_week event, intervals (5)
ltable survival_week event, graph								//produces graphs
ltable survival_week event, graph by(woman)
ltable survival_week event, failure graph

stset survival_week, failure(event)
sts graph, title(Surgery Survival Function) 					//Kaplan-Meier estimator
sts graph, title(Surgery Survival Function) censored(single)
sts graph, ci
label define woman 0 "Men" 1 "Women"							//compare two groups
sts list, by(woman)
sts graph, by(woman)
sts graph if woman==0, ci

sts test woman													//log-rank test
sts test woman, wilcoxon										//Wilcoxon-Breslaw-Gehan test
sts test woman, tware											//Taron-Ware test
sts test woman, peto											//Peto-Peto test

sts graph, hazard title(Surgery Hazard Function)				//Hazard function
sts graph, hazard by(woman)
sts graph, cumhaz												//Nelson-Aalen cumulative hazard plot
sts graph, by(woman) cumhaz


//Open the dataset Cox1.dta

stset survival_time, failure(event)
stcox woman treatment, nohr										//Cox proportional hazard model, raw coefficients
stcox woman treatment											//Cox model with hazard ratios

stphplot, by(woman)												//log-log plot
stcox treatment, strata(woman)									//stratification
stcox treatment woman, tvc(woman) texp(_t)						//interaction with time
stcox treatment woman, tvc(woman) texp(_t) nohr
stcox treatment if woman==0										//tests sub-groups
stcox treatment if woman==1


//Open the dataset Civil_war.dta

sort gwno year
tsset gwno year
gen lgdppc=l.gdppc
gen lgrowth=l.growth
gen llnpop=l.lnpop
tab war25

stset year, id(gwno) failure(war25==1)
stcox lgdppc lgrowth llnpop, vce(cluster gwno)							//Cox model with time-varying covariates 
stcox lgdppc lgrowth llnpop, nohr vce(cluster gwno)				//robust estimates of the variance and clustering

stset year, id(gwno) failure(war25==1) exit(time .)				//stset the data as multiple-events
stcox lgdppc lgrowth llnpop, nohr vce(cluster gwno)
stcox lgdppc lgrowth llnpop, vce(cluster gwno)

generate war3categories=0
replace war3categories=1 if war25==1
replace war3categories=2 if war1000==1
tab war3categories

stset year, id(gwno) failure(war3categories==1)
stcox lgdppc lgrowth llnpop, vce(cluster gwno)					//competing risks regression, small wars

sum lgdppc if e(sample)
stcurve, hazard kernel(gaussian) at1(lgdppc=72.325) at2(lgdppc=6564.382) at3(lgdppc=56389.210)	//hazard function for small wars, graph

stset year, id(gwno) failure(war3categories==2)
stcox lgdppc lgrowth llnpop, vce(cluster gwno)					//competing risks regression, big wars

sum lgdppc if e(sample)
stcurve, hazard kernel(gaussian) at1(lgdppc=72.325) at2(lgdppc=6076.416) at3(lgdppc=56389.210)	//hazard function for big wars, graph
